///////////////////////////////////////////////////////////
//  IGroupManager.cs
//  Implementation of the Interface IGroupChangePublisher
//  Generated by Enterprise Architect
//  Created on:      18-May-2018 16:16:39
//  Original author: simon.mettrick
///////////////////////////////////////////////////////////

using System;
using System.Collections.Generic;



using Org.OMG.TACSIT.DataInterface;
using Org.OMG.TACSIT.DataPayload.GroupPayload;
using Org.OMG.TACSIT.Controller;
namespace Org.OMG.TACSIT.DataInterface {
	/// <summary>
	/// Interface invoked as a callback when a group is created, modified or deleted.
	/// </summary>
	public interface IGroupChangePublisher {

		/// <summary>
		/// This method is called for each creation, modification and deletion of group.
		///      The implementation of this callback may return the exception StopListening
		/// as soon it wants to kill the listeners.
		/// </summary>
		event EventHandler<DataPayload.CallbackData.GroupChangeEvent> GroupChanged;
	}//end IGroupChangePublisher

	/// <summary>
	/// This interface allows to create and list groups. It is the entry point of the
	/// API.
	///      It must be noted that groups may be limited in number.
	/// </summary>
	public interface IGroupManager {

		/// <summary>
		/// Create a group from the given payload.
		///        The implementation shall return the GroupAlreadyKnown exception if the
		/// name is already used.
		///        The implementation may choose to limit the creation of groups existing
		/// in the system at the same time by returning either the TooManyGroups exception
		/// (when the number of groups is limited by the implementation) or the
		/// GroupCreationNotAllowed exception (when the creation of new groups is not
		/// allowed by the implementation).
		/// </summary>
		/// <param name="ovl"></param>
		Org.OMG.TACSIT.DataInterface.IGroup CreateGroup(Org.OMG.TACSIT.DataPayload.GroupPayload.GroupPayload ovl);

		/// <summary>
		/// List the references of the already defined groups filtered by their name
		/// (namePattern is a regexp).
		/// </summary>
		/// <param name="namePattern"></param>
		Org.OMG.TACSIT.DataPayload.GroupPayload.GroupList ListGroups(string namePattern);

		/// <summary>
		/// Get the interface to a group from its URI and return the UnknownURI exception
		/// if the entity does not exist (anymore).
		/// </summary>
		/// <param name="uri"></param>
		Org.OMG.TACSIT.DataInterface.IGroup GetGroup(Uri uri);

		/// <summary>
		/// Listen to the group creation, deletion, and update events at a given rate.
		///        This method may return the InadequateRate exception (if the
		/// implementation deems this parameter as unsuitable) or the TooManyListeners
		/// exception (if the implementation limit the number of listeners) or the
		/// NotImplemented exception if this capability is not available.
		/// </summary>
		/// <param name="rate"></param>
		Org.OMG.TACSIT.DataInterface.IGroupChangePublisher GetChangePublisher(int rate);

		/// <summary>
		/// Listen to the group creation, deletion, and update events.
		///        This method may return the TooManyListeners exception (if the
		/// implementation limit the number of listeners).
		/// </summary>
		Org.OMG.TACSIT.DataInterface.IGroupChangePublisher GetChangePublisher();

		/// <summary>
		/// Translate an Entity from the package Controller (from standard TCI) to the
		/// local Entity (from TEX). If not possible, the exception EntityUknown is thrown.
		/// 
		/// </summary>
		/// <param name="e"></param>
		Org.OMG.TACSIT.DataInterface.IEntity CastEntity(Org.OMG.TACSIT.Controller.IEntity e);
	}//end IGroupManager

}//end namespace DataInterface